@@ -8,7 +8,7 @@
 #
 if [ -z "$JVO_TOOLS" ]; then
    echo "you must set JVO_TOOLS"
-   exit 1
+   return 1
 fi
 
 #
@@ -86,3 +86,9 @@ for c in $p; do
    fi
 done
 
+#
+#
+#
+if [ -e ${ROOTSYS}/bin/thisroot.sh ]; then
+   . ${ROOTSYS}/bin/thisroot.sh
+fi
